#!/usr/bin/gnuplot

set term post eps enh color solid "Helvetica" 18
set out "aH_CPARAM.eps"
set size 0.8,0.6

# 0.2 H = log(delta a/C)

a_c = 2.8687750
C = 2.0e-4

H(a,a_c,C)= log10(abs(a-a_c)/C)/ 0.2

########################################################################

set xl "{/Helvetica-Oblique a}_p / AU"
set yl "{/Helvetica-Oblique H} / mag" offset 1,0

set xr [2.82:2.97]
y1=7
y2=17.5
set yr [y1:y2]
set xtics 0.05
set mxtics 5
set ytics 2
set mytics 2

set ticslevel 0
set samples 300
set key bottom samplen 0.5 font "Helvetica,14"
set lmargin 6.0
set rmargin 2.0
set bmargin 3.2
set tmargin 1.0

set style line 1 lt 9 pt 7  ps 0.33
set style line 2 lt 7 pt 70 ps 0.33
set style line 3 lt 1 lw 2
set style line 4 lt 7 lw 0.1

tmp=2.900; set label "   {/Helvetica-Oblique C} = 2.0 {/Symbol \264} 10^{{/Symbol -}4} AU"   at tmp, H(tmp,a_c,C)-0.5 left rotate by 0.0 font "Helvetica,10" front tc lt 1
tmp=2.900; set label "{/Symbol D}{/Helvetica-Oblique C} = 0.1 {/Symbol \264} 10^{{/Symbol -}4} AU" at tmp, graph 1.04 right rotate by 0.0 font "Helvetica,10" front

p \
  H(x,a_c,0.10e-4) not ls 4,\
  H(x,a_c,0.20e-4) not ls 4,\
  H(x,a_c,0.30e-4) not ls 4,\
  H(x,a_c,0.40e-4) not ls 4,\
  H(x,a_c,0.50e-4) not ls 4,\
  H(x,a_c,0.60e-4) not ls 4,\
  H(x,a_c,0.70e-4) not ls 4,\
  H(x,a_c,0.80e-4) not ls 4,\
  H(x,a_c,0.90e-4) not ls 4,\
  H(x,a_c,1.00e-4) not ls 4,\
  H(x,a_c,1.10e-4) not ls 4,\
  H(x,a_c,1.20e-4) not ls 4,\
  H(x,a_c,1.30e-4) not ls 4,\
  H(x,a_c,1.40e-4) not ls 4,\
  H(x,a_c,1.50e-4) not ls 4,\
  H(x,a_c,1.60e-4) not ls 4,\
  H(x,a_c,1.70e-4) not ls 4,\
  H(x,a_c,1.80e-4) not ls 4,\
  H(x,a_c,1.90e-4) not ls 4,\
  H(x,a_c,2.00e-4) not ls 4,\
  "vline.dat" u (a_c):(y1+(y2-y1)*$2) not w l ls 4,\
  "family.list_50"   u 3:2 t "Koronis family, {/Helvetica-Oblique v}_{cutoff} = 50 m/s" ls 1,\
  "interlopers.out"  u 3:2 t "interlopers"                                      ls 2,\
  H(x,a_c,C)   not ls 3,\
  "<awk '($1==158)' family.list_50" u 3:2:(sprintf(" (%d) ",$1)) not w labels right font "Helvetica,10"
q












  H(x,a_c,0.04e-4) not ls 4,\
  H(x,a_c,0.08e-4) not ls 4,\
  H(x,a_c,0.12e-4) not ls 4,\
  H(x,a_c,0.16e-4) not ls 4,\
  H(x,a_c,0.20e-4) not ls 4,\
  H(x,a_c,0.24e-4) not ls 4,\
  H(x,a_c,0.28e-4) not ls 4,\
  H(x,a_c,0.32e-4) not ls 4,\
  H(x,a_c,0.36e-4) not ls 4,\
  H(x,a_c,0.40e-4) not ls 4,\
  H(x,a_c,0.44e-4) not ls 4,\
  H(x,a_c,0.48e-4) not ls 4,\
  H(x,a_c,0.52e-4) not ls 4,\
  H(x,a_c,0.56e-4) not ls 4,\
  H(x,a_c,0.60e-4) not ls 4,\
  H(x,a_c,0.64e-4) not ls 4,\
  H(x,a_c,0.68e-4) not ls 4,\
  H(x,a_c,0.72e-4) not ls 4,\
  H(x,a_c,0.76e-4) not ls 4,\
  H(x,a_c,0.80e-4) not ls 4,\
  H(x,a_c,0.84e-4) not ls 4,\
  H(x,a_c,0.88e-4) not ls 4,\
  H(x,a_c,0.92e-4) not ls 4,\
  H(x,a_c,0.96e-4) not ls 4,\
  H(x,a_c,1.00e-4) not ls 4,\
  H(x,a_c,1.04e-4) not ls 4,\
  H(x,a_c,1.08e-4) not ls 4,\
  H(x,a_c,1.12e-4) not ls 4,\
  H(x,a_c,1.16e-4) not ls 4,\
  H(x,a_c,1.20e-4) not ls 4,\
  H(x,a_c,1.24e-4) not ls 4,\
  H(x,a_c,1.28e-4) not ls 4,\
  H(x,a_c,1.32e-4) not ls 4,\
  H(x,a_c,1.36e-4) not ls 4,\
  H(x,a_c,1.40e-4) not ls 4,\
  H(x,a_c,1.44e-4) not ls 4,\
  H(x,a_c,1.48e-4) not ls 4,\
  H(x,a_c,1.52e-4) not ls 4,\
  H(x,a_c,1.56e-4) not ls 4,\
  H(x,a_c,1.60e-4) not ls 4,\
  H(x,a_c,1.64e-4) not ls 4,\
  H(x,a_c,1.68e-4) not ls 4,\
  H(x,a_c,1.72e-4) not ls 4,\
  H(x,a_c,1.76e-4) not ls 4,\
  H(x,a_c,1.80e-4) not ls 4,\
  H(x,a_c,1.84e-4) not ls 4,\
  H(x,a_c,1.88e-4) not ls 4,\
  H(x,a_c,1.92e-4) not ls 4,\
  H(x,a_c,1.96e-4) not ls 4,\
  "<awk '($1==579)' family.list_50" u 3:2:1 not w labels,\
  "<awk '($1==639)' family.list_50" u 3:2:1 not w labels

